<?php

Class TAnalytics
{ 
   static private $TControl=NULL;

   public function __construct(TControl $TControl)
   {
        self::$TControl = $TControl;
        // Load the Google API PHP Client Library.
        require_once _TB_PATHAPIS . 'google-api/vendor/autoload.php';
   }

   public function start()
   {
        $VIEW_ID="163512282";
        if(self::$TControl->TSession->issetVar("ceiboo.analytics.".$VIEW_ID)) {
            $report=self::$TControl->TSession->getVar("ceiboo.analytics.".$VIEW_ID);
        } else {
            $analytics = $this->initializeAnalytics();
    
            $responseToday = $this->getReport($analytics,$VIEW_ID,"today","today");
            $responseYesterday = $this->getReport($analytics,$VIEW_ID,"yesterday","yesterday");
            $response2day = $this->getReport($analytics,$VIEW_ID,date("Y-m-d",strtotime("-2 day")),date("Y-m-d",strtotime("-2 day")));
            $response3day = $this->getReport($analytics,$VIEW_ID,date("Y-m-d",strtotime("-3 day")),date("Y-m-d",strtotime("-3 day")));
            $response4day = $this->getReport($analytics,$VIEW_ID,date("Y-m-d",strtotime("-4 day")),date("Y-m-d",strtotime("-4 day")));
            $response5day = $this->getReport($analytics,$VIEW_ID,date("Y-m-d",strtotime("-5 day")),date("Y-m-d",strtotime("-5 day")));
            $response6day = $this->getReport($analytics,$VIEW_ID,date("Y-m-d",strtotime("-6 day")),date("Y-m-d",strtotime("-6 day")));
            $response7day = $this->getReport($analytics,$VIEW_ID,date("Y-m-d",strtotime("-7 day")),date("Y-m-d",strtotime("-7 day")));
            $responseLast7 = $this->getReport($analytics,$VIEW_ID,"7daysAgo","today");
            $responseLast30 = $this->getReport($analytics,$VIEW_ID,"30daysAgo","today");
            $responseMonth = $this->getReport($analytics,$VIEW_ID,date("Y")."-".date("m")."-01","today");
            $responseYear = $this->getReport($analytics,$VIEW_ID,date("Y")."-01-01","today");
            
            $report=array("hoy"=>$responseToday->reports[0]->data->totals[0]->values[0], 
            "ayer"=>$responseYesterday->reports[0]->data->totals[0]->values[0], 
            "2dias"=>$response2day->reports[0]->data->totals[0]->values[0], 
            "3dias"=>$response3day->reports[0]->data->totals[0]->values[0], 
            "4dias"=>$response4day->reports[0]->data->totals[0]->values[0], 
            "5dias"=>$response5day->reports[0]->data->totals[0]->values[0], 
            "6dias"=>$response6day->reports[0]->data->totals[0]->values[0], 
            "7dias"=>$response7day->reports[0]->data->totals[0]->values[0], 
            "ultimos7"=>$responseLast7->reports[0]->data->totals[0]->values[0], 
            "ultimos30"=>$responseLast30->reports[0]->data->totals[0]->values[0], 
            "mes"=>$responseMonth->reports[0]->data->totals[0]->values[0], 
            "año"=>$responseYear->reports[0]->data->totals[0]->values[0]);
    
            self::$TControl->TSession->setVar("ceiboo.analytics.".$VIEW_ID,$report);

        }    
        return $report;
   } 

    /**
     * Initializes an Analytics Reporting API V4 service object.
     *
     * @return An authorized Analytics Reporting API V4 service object.
     */
    public function initializeAnalytics()
    {

        // Use the developers console and download your service account
        // credentials in JSON format. Place them in this directory or
        // change the key file location if necessary.
        $KEY_FILE_LOCATION = _TB_PATHBASE . 'middleware/includes/NewsCeiboo-322e3f834a4c.json';

        // Create and configure a new client object.
        $client = new Google_Client();
        $client->setApplicationName("Hello Analytics Reporting");
        $client->setAuthConfig($KEY_FILE_LOCATION);
        $client->setScopes(['https://www.googleapis.com/auth/analytics.readonly']);
        $analytics = new Google_Service_AnalyticsReporting($client);

        return $analytics;
    }

    /**
     * Queries the Analytics Reporting API V4.
     *
     * @param service An authorized Analytics Reporting API V4 service object.
     * @return The Analytics Reporting API V4 response.
     */
    public function getReport($analytics,$VIEW_ID="163512282",$startDate="today",$endDate="today") {

        // Replace with your view ID, for example XXXX.
        //$VIEW_ID = "163512282";

        // Create the DateRange object.
        $dateRange = new Google_Service_AnalyticsReporting_DateRange();
        $dateRange->setStartDate($startDate);
        $dateRange->setEndDate($endDate);

        // Create the Metrics object.
        $sessions = new Google_Service_AnalyticsReporting_Metric();
        $sessions->setExpression("ga:pageviews");
        $sessions->setAlias("pageviews");

        // Create the ReportRequest object.
        $request = new Google_Service_AnalyticsReporting_ReportRequest();
        $request->setViewId($VIEW_ID);
        $request->setDateRanges($dateRange);
        $request->setMetrics(array($sessions));

        $body = new Google_Service_AnalyticsReporting_GetReportsRequest();
        $body->setReportRequests( array( $request) );
        return $analytics->reports->batchGet( $body );
    }

    /**
     * Parses and prints the Analytics Reporting API V4 response.
     *
     * @param An Analytics Reporting API V4 response.
     */
    public function printResults($reports) {
        var_dump($reports);

        for ( $reportIndex = 0; $reportIndex < count( $reports ); $reportIndex++ ) {
            $report = $reports[ $reportIndex ];
            $header = $report->getColumnHeader();
            $dimensionHeaders = $header->getDimensions();
            $metricHeaders = $header->getMetricHeader()->getMetricHeaderEntries();
            $rows = $report->getData()->getRows();

            for ( $rowIndex = 0; $rowIndex < count($rows); $rowIndex++) {
            $row = $rows[ $rowIndex ];
            $dimensions = $row->getDimensions();
            $metrics = $row->getMetrics();
            for ($i = 0; $i < count($dimensionHeaders) && $i < count($dimensions); $i++) {
                print($dimensionHeaders[$i] . ": " . $dimensions[$i] . "\n");
            }

            for ($j = 0; $j < count($metrics); $j++) {
                $values = $metrics[$j]->getValues();
                for ($k = 0; $k < count($values); $k++) {
                $entry = $metricHeaders[$k];
                print($entry->getName() . ": " . $values[$k] . "\n");
                }
            }
            }
        }
    }
   
} 
?>
