<?php
/**
* TSession.php 
*
* Es la clase que administra las variables de Session de toda la aplicacion
*
* @author José Luis Alfaro <joseluis@tbackend.com.ar>
* @link http://www.tbackend.com.ar/
* @copyright Copyright &copy; 2009 ceiboo.com
* @since     Versión 3.0, revisión 20090601.
* @version   3.0
* @package TSession
*/

class TSession
	{
		static private $valid = false;
		static private $TControl=NULL;
		
		public function __construct(TControl $TControl)
			{
				self::$TControl = $TControl;
				session_cache_expire(5);
			}
		
		public function startSession($id = false)
			{
				if($id===false) {
					session_id();	
				} else {
					session_id($id);	
				}
				session_start();
				header('P3P: CP="NOI ADM DEV PSAi COM NAV OUR OTRo STP IND DEM"');
				header("Cache-control: private");
			}
			
		/**
		* private function start()
		*
		* Inicializa la classe session.
		*/
		public function start()
			{
				self::startSession();
				if(self::isSetVar("ceiboo.template"))
					{
						$valid = true;
					} else {
						if(isset($_GET["template"]))
						{
							$this->setVar("ceiboo.template",$_GET["template"]);
							$valid = true;
						} else {
							$valid = false;
						}
						
					}
				return $valid;
			}
		
		/**
		* Permite almacenar una variable de session.
		*
		* @param   string  $name      El nombre que va a tomar la variable de session.
		* @param   string  $value		El valor que se almacena en la variable definida.
		*
		*	<code>
		*		self::$TControl->TSession->setVar("cart",52352);
		*		self::$TControl->TSession->setVar("config.ip", "192.168.0.1");
		* </code>
		*
		* @example Si se envia un nombre de variable con punto, entonces nos almacena en array multidimensionales. ej: setVar("config.ip", "192.168.0.1") <=> $_SESSION['config']['ip'] = "192.168.0.1"
		*/
		public function setVar($name, $value)
			{
				if(!empty($name))
					{
						$expr = self::getCellNames($name);
						$expr .= " = \$value;";
						eval($expr);
					}
			}
			
			
		
		/**
		* Permite obtener el valor de una variable de session.
		*
		* @param   string  $name      El nombre de la variable de session que queremos recuperar.
		*
		* @return   mixed		Retorna el valor de la variable.
		*
		*	<code>
		*		self::$TControl->TSession->getVar("cart");
		*		self::$TControl->TSession->getVar("config.ip");
		* </code>
		*
		* @example Si se envia un nombre de variable con punto, entonces nos retornará el valor del array multidimensional. ej: getVar("config.ip") <=> $_SESSION['config']['ip']
		*/
		public function getVar($name)
			{
				if(self::isSetVar($name))
					{
						$result = eval("return ".self::getCellNames($name).";");
						return $result;
					}
				die ($name." no se ha cargado en session.");
				return false;
			}
		
		
		
		/**
		* Permite eliminar una variable de session.
		*
		* @param   string  $name      El nombre de la variable de session que queremos eliminar.
		*
		* @return   boolean		Retorna true si se logro o false sino se logro borrar.
		*
		*	<code>
		*		self::$TControl->TSession->unSetVar("cart");
		*		self::$TControl->TSession->unSetVar("config.ip");
		* </code>
		*
		* @example Si se envia un nombre de variable con punto, entonces nos eliminará el array multidimensional. ej: unSetVar("config.ip") <=> unSet($_SESSION['config']['ip'])
		*/
		public function unsetVar($name)
			{
				if( self::isSetVar($name) )
					{
						$var = self::getCellNames($name);
						eval("unset($var);");
						return true;
					}
				return false;
			}
		
		
		
		/**
		* Permite verificar si existe una variable de session.
		*
		* @param   string  $name      El nombre de la variable de session que queremos eliminar.
		*
		* @return   boolean		Retorna true si  existe o false sino.
		*
		* <code>
		*		self::$TControl->TSession->isSetVar("cart");
		*		self::$TControl->TSession->isSetVar("config.ip");
		* </code>
		*
		* @example Si se envia un nombre de variable con punto, entonces nos verifica si existe el array multidimensional. ej: isSetVar("config.ip") <=> isSet($_SESSION['config']['ip'])
		*/
		public function isSetVar($name)
			{
				$expr = "return isset(".self::getCellNames($name).");";
				return eval($expr);
			}
		
		/**
		* @access private
		* 
		* Funcion privada que devuelve el array $_SESSION armado.
		*
		* @param   string  $name      El nombre de la variable de session que queremos armar.
		*
		* @return   boolean		Retorna el array de SESSION o false.
		*
		*	<code>
		*		self::getCellNames($name);
		* </code>
		*
		*/
		private function getCellNames($name)
			{
				if(is_string($name))
					{
						if(strpos($name, ".")) 
							{ $names = explode(".", $name);}
						else
							{$names = array($name);}
					
						$expr = $expr = "\$_SESSION";
						foreach($names as $item)
							{ $expr.= is_numeric($item) ? "[$item]" : "['$item']"; }
					
						return $expr;
					}
				
				//self::$TControl->TError->executionError("$name isn't a string");
				return false;
		}

		/**
		* 
		* Devuelve el ID de la session actual.
		*
		* @return   string		SESSIONID
		*
		*	<code>
		*		self::$TControl->TSession->getID();
		* </code>
		*
		*/
		public function getID()
			{
				return session_id();
			}
					

		
		/** Add a session identifier to an url
		* $url
		*/    
		public function appendSID($url)
			{
				$sid = "";
				if(strlen(SID))
					{
						if(strpos($url, "?") === true)
							{ $sep = "&";}
						else
							{ $sep = "?"; }
					
						$sid = $sep.SID;
					}
				return $url.$sid;
			}

	public function close()
		{
			session_unset();			
		}
		
	
	}	
?>